@@ -39,7 +39,7 @@ ImportExportDialog::~ImportExportDialog()
     delete ui;
 }
 
-QString ImportExportDialog::getFilePath()
+QString ImportExportDialog::getFilePath() const
 {
     return m_filePaths.isEmpty() ? QString() : m_filePaths.first();
 }
@@ -83,7 +83,7 @@ void ImportExportDialog::setFileExtension(QString extension)
     for (int i = 0; i < m_filePaths.size(); i++)
     {
         QFileInfo info(m_filePaths.at(i));
-        m_filePaths.replace(i, info.path() + "/" + info.baseName() + "." + extension);
+        m_filePaths.replace(i, info.path() + "/" + info.completeBaseName() + "." + extension);
     }
     ui->fileEdit->setText("\"" + m_filePaths.join("\" \"") + "\"");
 
