@@ -55,8 +55,8 @@ class MainWindow2 : public QMainWindow
     Q_OBJECT
 
 public:
-    explicit MainWindow2(QWidget* parent = 0);
-    ~MainWindow2();
+    explicit MainWindow2(QWidget* parent = nullptr);
+    ~MainWindow2() override;
 
     Editor* mEditor = nullptr;
 
@@ -78,6 +78,8 @@ public:
     // import
     void importImage();
     void importImageSequence();
+    void importImageSequenceNumbered();
+    void addLayerByFilename(QString strFilePath);
     void importMovie();
     void importGIF();
 
