@@ -42,7 +42,7 @@ struct CanvasPainterOptions
     bool  bAntiAlias = false;
     bool  bGrid = false;
     int   nGridSizeW = 50; /* This is the grid Width IN PIXELS. The grid will scale with the image, though */
-    int   nGridSizeH = 50; /* This is the grid Heigth IN PIXELS. The grid will scale with the image, though */
+    int   nGridSizeH = 50; /* This is the grid Height IN PIXELS. The grid will scale with the image, though */
     bool  bAxis = false;
     bool  bThinLines = false;
     bool  bOutlines = false;
