@@ -17,10 +17,22 @@ GNU General Public License for more details.
 
 
 #include "basedockwidget.h"
+#include "platformhandler.h"
 
 BaseDockWidget::BaseDockWidget(QWidget* pParent) 
 : QDockWidget(pParent, Qt::Tool)
 {
+
+#ifdef __APPLE__
+    if (PlatformHandler::isDarkMode())
+    {
+        setStyleSheet("QDockWidget::title { background: QLinearGradient( x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #4e4f4d, stop: 1 #424241);  "
+                      "background-repeat: repeat-x; text-align: center;"
+                      "border-style: solid; border-bottom-color: #000000;"
+                      "border-width: 1px; }");
+    }
+#endif
+
 }
 
 BaseDockWidget::~BaseDockWidget()
