@@ -480,11 +480,16 @@ void Editor::updateAutoSaveCounter()
     mAutosaveCounter++;
     if (mAutosaveCounter >= mAutosaveNumber)
     {
-        mAutosaveCounter = 0;
+        resetAutoSaveCounter();
         emit needSave();
     }
 }
 
+void Editor::resetAutoSaveCounter()
+{
+    mAutosaveCounter = 0;
+}
+
 void Editor::cut()
 {
     copy();
@@ -918,6 +923,12 @@ KeyFrame* Editor::addKeyFrame(int layerNumber, int frameIndex)
         return nullptr;
     }
 
+    if (!layer->visible())
+    {
+        mScribbleArea->showLayerNotVisibleWarning();
+        return nullptr;
+    }
+
     while (layer->keyExists(frameIndex))
     {
         frameIndex += 1;
@@ -934,6 +945,14 @@ KeyFrame* Editor::addKeyFrame(int layerNumber, int frameIndex)
 void Editor::removeKey()
 {
     Layer* layer = layers()->currentLayer();
+    Q_ASSERT(layer != nullptr);
+
+    if (!layer->visible())
+    {
+        mScribbleArea->showLayerNotVisibleWarning();
+        return;
+    }
+
     if (!layer->keyExistsWhichCovers(currentFrame()))
     {
         return;
@@ -941,6 +960,7 @@ void Editor::removeKey()
 
     backup(tr("Remove frame"));
 
+    mScribbleArea->deselectAll();
     layer->removeKeyFrame(currentFrame());
 
     scrubBackward();
@@ -974,6 +994,11 @@ void Editor::switchVisibilityOfLayer(int layerNumber)
     emit updateTimeLine();
 }
 
+void Editor::showLayerNotVisibleWarning()
+{
+    return mScribbleArea->showLayerNotVisibleWarning();
+}
+
 void Editor::swapLayers(int i, int j)
 {
     mObject->swapLayers(i, j);
