@@ -138,6 +138,7 @@ public: //slots
     void removeKey();
 
     void switchVisibilityOfLayer(int layerNumber);
+    void showLayerNotVisibleWarning();
     void swapLayers(int i, int j);
 
     void backup(QString undoText);
@@ -157,6 +158,7 @@ public: //slots
 
     void dontAskAutoSave(bool b) { mAutosaveNerverAskAgain = b; }
     bool autoSaveNeverAskAgain() { return mAutosaveNerverAskAgain; }
+    void resetAutoSaveCounter();
 
 protected:
     // Need to move to somewhere...
