@@ -58,7 +58,7 @@ class ScribbleArea : public QWidget
 
 public:
     ScribbleArea(QWidget* parent);
-    ~ScribbleArea();
+    ~ScribbleArea() override;
 
     bool init();
     void setEditor(Editor* e) { mEditor = e; }
@@ -88,7 +88,6 @@ public:
     qreal myRotatedAngle = 0.0;
     QList<int> mClosestCurves;
 
-    bool areLayersSane() const;
     bool isLayerPaintable() const;
     bool allowSmudging();
 
