@@ -54,7 +54,8 @@ void PreferenceManager::loadPrefs()
     set(SETTING::OUTLINES,                 settings.value(SETTING_OUTLINES,               false).toBool());
 
     // Grid
-    set(SETTING::GRID_SIZE,                settings.value(SETTING_GRID_SIZE,               50).toInt());
+    set(SETTING::GRID_SIZE_W,              settings.value(SETTING_GRID_SIZE_W,            100).toInt());
+    set(SETTING::GRID_SIZE_H,              settings.value(SETTING_GRID_SIZE_H,            100).toInt());
 
     // General
     set(SETTING::ANTIALIAS,                settings.value(SETTING_ANTIALIAS,              true).toBool());
@@ -70,6 +71,11 @@ void PreferenceManager::loadPrefs()
     set(SETTING::BACKGROUND_STYLE,         settings.value(SETTING_BACKGROUND_STYLE,       "white").toString());
 
     set(SETTING::LAYOUT_LOCK,              settings.value(SETTING_LAYOUT_LOCK,            false).toBool());
+    set(SETTING::FRAME_POOL_SIZE,          settings.value(SETTING_FRAME_POOL_SIZE,        200).toInt());
+
+    set(SETTING::FPS,                      settings.value(SETTING_FPS,                    12).toInt());
+    set(SETTING::FIELD_W,                  settings.value(SETTING_FIELD_W,                800).toInt());
+    set(SETTING::FIELD_H,                  settings.value(SETTING_FIELD_H,                600).toInt());
 
     // Files
     set(SETTING::AUTO_SAVE,                settings.value(SETTING_AUTO_SAVE,              true ).toBool());
@@ -99,6 +105,10 @@ void PreferenceManager::loadPrefs()
     set(SETTING::ONION_WHILE_PLAYBACK,     settings.value(SETTING_ONION_WHILE_PLAYBACK,   0).toInt());
     set(SETTING::ONION_TYPE,               settings.value(SETTING_ONION_TYPE,             "relative").toString());
 
+    set(SETTING::FLIP_ROLL_MSEC,           settings.value(SETTING_FLIP_ROLL_MSEC,         100).toInt());
+    set(SETTING::FLIP_ROLL_DRAWINGS,       settings.value(SETTING_FLIP_ROLL_DRAWINGS,     5).toInt());
+    set(SETTING::FLIP_INBETWEEN_MSEC,      settings.value(SETTING_FLIP_INBETWEEN_MSEC,    100).toInt());
+
     set(SETTING::LANGUAGE,                 settings.value(SETTING_LANGUAGE).toString());
 }
 
@@ -187,7 +197,7 @@ void PreferenceManager::set(SETTING option, int value)
         break;
     case SETTING::FRAME_SIZE:
         if (value < 4) { value = 4; }
-        else if (value > 20) { value = 20; }
+        else if (value > 40) { value = 40; }
         settings.setValue(SETTING_FRAME_SIZE, value);
         break;
     case SETTING::TIMELINE_SIZE:
@@ -210,8 +220,23 @@ void PreferenceManager::set(SETTING option, int value)
     case SETTING::ONION_NEXT_FRAMES_NUM:
         settings.setValue(SETTING_ONION_NEXT_FRAMES_NUM, value);
         break;
-    case SETTING::GRID_SIZE:
-        settings.setValue(SETTING_GRID_SIZE, value);
+    case SETTING::FLIP_ROLL_MSEC :
+        settings.setValue(SETTING_FLIP_ROLL_MSEC, value);
+        break;
+    case SETTING::FLIP_ROLL_DRAWINGS :
+        settings.setValue(SETTING_FLIP_ROLL_DRAWINGS, value);
+        break;
+    case SETTING::FLIP_INBETWEEN_MSEC :
+        settings.setValue(SETTING_FLIP_INBETWEEN_MSEC, value);
+        break;
+    case SETTING::GRID_SIZE_W:
+        settings.setValue(SETTING_GRID_SIZE_W, value);
+        break;
+    case SETTING::GRID_SIZE_H:
+        settings.setValue(SETTING_GRID_SIZE_H, value);
+        break;
+    case SETTING::FRAME_POOL_SIZE:
+        settings.setValue(SETTING_FRAME_POOL_SIZE, value);
         break;
     case SETTING::DRAW_ON_EMPTY_FRAME_ACTION:
         settings.setValue( SETTING_DRAW_ON_EMPTY_FRAME_ACTION, value);
@@ -219,6 +244,15 @@ void PreferenceManager::set(SETTING option, int value)
     case SETTING::ONION_WHILE_PLAYBACK:
         settings.setValue(SETTING_ONION_WHILE_PLAYBACK, value);
         break;
+    case SETTING::FPS:
+        settings.setValue(SETTING_FPS, value);
+        break;
+    case SETTING::FIELD_W:
+        settings.setValue(SETTING_FIELD_W, value);
+        break;
+    case SETTING::FIELD_H:
+        settings.setValue(SETTING_FIELD_H, value);
+        break;
     default:
         Q_ASSERT(false);
         break;
