@@ -24,7 +24,8 @@ GNU General Public License for more details.
 #include <QHBoxLayout>
 #include <QtDebug>
 #include "camera.h"
-
+#include <qsettings.h>
+#include "pencildef.h"
 
 CameraPropertiesDialog::CameraPropertiesDialog(QString name, int width, int height) :
     QDialog(),
@@ -77,8 +78,16 @@ void CameraPropertiesDialog::setHeight(int height)
 LayerCamera::LayerCamera( Object* object ) : Layer( object, Layer::CAMERA )
 {
     setName(tr("Camera Layer"));
-    viewRect = QRect(QPoint(-400, -300), QSize(800, 600));
-    dialog = NULL;
+    QSettings settings (PENCIL2D, PENCIL2D);
+    mFieldW = settings.value("FieldW").toInt();
+    mFieldH = settings.value("FieldH").toInt();
+    if (mFieldW < 2 || mFieldH < 2)
+    {
+        mFieldW = 800;
+        mFieldH = 600;
+    }
+    viewRect = QRect(QPoint(-mFieldW/2, -mFieldH/2), QSize(mFieldW, mFieldH));
+    dialog = nullptr;
 }
 
 LayerCamera::~LayerCamera()
@@ -107,15 +116,15 @@ QTransform LayerCamera::getViewAtFrame(int frameNumber)
     int nextFrame = getNextKeyFramePosition( frameNumber );
 	Camera* camera2 = static_cast< Camera* >( getLastKeyFrameAtPosition( nextFrame ) );
 
-    if (camera1 == NULL && camera2 == NULL)
+    if (camera1 == nullptr && camera2 == nullptr)
     {
         return QTransform();
     }
-    else if (camera1 == NULL && camera2 != NULL)
+    else if (camera1 == nullptr && camera2 != nullptr)
     {
         return camera2->view;
     }
-    else if (camera2 == NULL && camera1 != NULL)
+    else if (camera2 == nullptr && camera1 != nullptr)
     {
         return camera1->view;
     }
@@ -157,15 +166,15 @@ void LayerCamera::linearInterpolateTransform(Camera* cam)
     int nextFrame = getNextKeyFramePosition(frameNumber);
     Camera* camera2 = static_cast<Camera*>(getLastKeyFrameAtPosition(nextFrame));
 
-    if (camera1 == NULL && camera2 == NULL)
+    if (camera1 == nullptr && camera2 == nullptr)
     {
         return; // do nothing
     }
-    else if (camera1 == NULL && camera2 != NULL)
+    else if (camera1 == nullptr && camera2 != nullptr)
     {
         return cam->assign(*camera2);
     }
-    else if (camera2 == NULL && camera1 != NULL)
+    else if (camera2 == nullptr && camera1 != nullptr)
     {
         return cam->assign(*camera1);
     }
@@ -206,7 +215,7 @@ QSize LayerCamera::getViewSize()
     return viewRect.size();
 }
 
-void LayerCamera::loadImageAtFrame( int frameNumber, float dx, float dy, float rotate, float scale)
+void LayerCamera::loadImageAtFrame( int frameNumber, qreal dx, qreal dy, qreal rotate, qreal scale)
 {
     if ( keyExists( frameNumber ) )
     {
@@ -232,7 +241,7 @@ KeyFrame* LayerCamera::createKeyFrame(int position, Object*)
 
 void LayerCamera::editProperties()
 {
-    if ( dialog == NULL )
+    if ( dialog == nullptr )
     {
         dialog = new CameraPropertiesDialog( name(), viewRect.width(), viewRect.height() );
     }
@@ -243,6 +252,9 @@ void LayerCamera::editProperties()
     if (result == QDialog::Accepted)
     {
         setName( dialog->getName() );
+        QSettings settings (PENCIL2D, PENCIL2D);
+        settings.setValue(SETTING_FIELD_W, dialog->getWidth());
+        settings.setValue(SETTING_FIELD_H, dialog->getHeight());
         viewRect = QRect(-dialog->getWidth()/2, -dialog->getHeight()/2, dialog->getWidth(), dialog->getHeight());
 
         emit resolutionChanged();
