@@ -28,13 +28,12 @@ public:
     explicit EraserTool( QObject* parent = 0 );
     ToolType type() override;
     void loadSettings() override;
+    void resetToDefault() override;
     QCursor cursor() override;
 
-    void mouseMoveEvent( QMouseEvent* ) override;
-    void mousePressEvent( QMouseEvent* ) override;
-    void mouseReleaseEvent( QMouseEvent* ) override;
-
-    void adjustPressureSensitiveProperties( qreal pressure, bool mouseDevice ) override;
+    void pointerMoveEvent( PointerEvent* ) override;
+    void pointerPressEvent( PointerEvent* ) override;
+    void pointerReleaseEvent( PointerEvent* ) override;
 
     void drawStroke();
     void paintAt( QPointF point );
@@ -44,7 +43,7 @@ public:
     void setWidth( const qreal width ) override;
     void setFeather( const qreal feather ) override;
     void setPressure( const bool pressure ) override;
-    void setInpolLevel(const int level) override;
+    void setStabilizerLevel(const int level) override;
 
 protected:
     QPointF mLastBrushPoint;
