@@ -34,9 +34,9 @@ public:
     void loadSettings() override;
     QCursor cursor() override;
 
-    void mousePressEvent(QMouseEvent*) override;
-    void mouseReleaseEvent(QMouseEvent*) override;
-    void mouseMoveEvent(QMouseEvent*) override;
+    void pointerPressEvent(PointerEvent*) override;
+    void pointerReleaseEvent(PointerEvent*) override;
+    void pointerMoveEvent(PointerEvent*) override;
 
     bool leavingThisTool() override;
     bool switchingLayer() override;
@@ -53,13 +53,13 @@ private:
 
     int showTransformWarning();
 
-    void beginInteraction(QMouseEvent* event, Layer* layer);
-    void createVectorSelection(QMouseEvent* event, Layer* layer);
-    void transformSelection(QMouseEvent* event, Layer* layer);
+    void beginInteraction(Qt::KeyboardModifiers keyMod, Layer* layer);
+    void createVectorSelection(Qt::KeyboardModifiers keyMod, Layer* layer);
+    void transformSelection(Qt::KeyboardModifiers keyMod, Layer* layer);
     void storeClosestVectorCurve(Layer* layer);
 
-    void setCurveSelected(VectorImage* vectorImage, QMouseEvent* event);
-    void setAreaSelected(VectorImage* vectorImage, QMouseEvent* event);
+    void setCurveSelected(VectorImage* vectorImage, Qt::KeyboardModifiers keyMod);
+    void setAreaSelected(VectorImage* vectorImage, Qt::KeyboardModifiers keyMod);
 
     bool transformHasBeenModified();
     bool shouldDeselect();
