@@ -26,22 +26,21 @@ class PenTool : public StrokeTool
 {
     Q_OBJECT
 public:
-    PenTool(QObject *parent = 0);
+    PenTool(QObject* parent = 0);
     ToolType type() override { return PEN; }
     void loadSettings() override;
     QCursor cursor() override;
+    void resetToDefault() override;
 
-    void mousePressEvent(QMouseEvent*) override;
-    void mouseMoveEvent(QMouseEvent*) override;
-    void mouseReleaseEvent(QMouseEvent*) override;
+    void pointerPressEvent(PointerEvent*) override;
+    void pointerMoveEvent(PointerEvent*) override;
+    void pointerReleaseEvent(PointerEvent*) override;
 
     void drawStroke();
     void paintAt(QPointF point);
     void paintVectorStroke(Layer *layer);
     void paintBitmapStroke();
 
-    void adjustPressureSensitiveProperties(qreal pressure, bool mouseDevice) override;
-
     void setWidth(const qreal width) override;
     void setPressure(const bool pressure) override;
     void setAA(const int AA) override;
