@@ -36,42 +36,41 @@ extern "C" {
 }
 #endif
 
-StrokeTool::StrokeTool( QObject *parent ) :
-BaseTool( parent )
+StrokeTool::StrokeTool(QObject* parent) : BaseTool(parent)
 {
     detectWhichOSX();
 }
 
 void StrokeTool::startStroke()
 {
-    if(emptyFrameActionEnabled())
+    if (emptyFrameActionEnabled())
     {
         mScribbleArea->handleDrawingOnEmptyFrame();
     }
 
     mFirstDraw = true;
     mLastPixel = getCurrentPixel();
-    
+
     mStrokePoints.clear();
 
     //Experimental
-    QPointF startStrokes =  m_pStrokeManager->interpolateStart(mLastPixel);
-    mStrokePoints << mEditor->view()->mapScreenToCanvas( startStrokes );
+    QPointF startStrokes = strokeManager()->interpolateStart(mLastPixel);
+    mStrokePoints << mEditor->view()->mapScreenToCanvas(startStrokes);
 
     mStrokePressures.clear();
-    mStrokePressures << m_pStrokeManager->getPressure();
+    mStrokePressures << strokeManager()->getPressure();
 
     disableCoalescing();
 }
 
 bool StrokeTool::keyPressEvent(QKeyEvent *event)
 {
-    switch ( event->key() ) {
+    switch (event->key()) {
     case Qt::Key_Alt:
-        mScribbleArea->setTemporaryTool( EYEDROPPER );
+        mScribbleArea->setTemporaryTool(EYEDROPPER);
         return true;
     case Qt::Key_Space:
-        mScribbleArea->setTemporaryTool( HAND ); // just call "setTemporaryTool()" to activate temporarily any tool
+        mScribbleArea->setTemporaryTool(HAND); // just call "setTemporaryTool()" to activate temporarily any tool
         return true;
     }
     return false;
@@ -90,8 +89,8 @@ bool StrokeTool::emptyFrameActionEnabled()
 
 void StrokeTool::endStroke()
 {
-    m_pStrokeManager->interpolateEnd();
-    mStrokePressures << m_pStrokeManager->getPressure();
+    strokeManager()->interpolateEnd();
+    mStrokePressures << strokeManager()->getPressure();
     mStrokePoints.clear();
     mStrokePressures.clear();
 
@@ -101,14 +100,12 @@ void StrokeTool::endStroke()
 void StrokeTool::drawStroke()
 {
     QPointF pixel = getCurrentPixel();
-    if ( pixel != mLastPixel || !mFirstDraw )
+    if (pixel != mLastPixel || !mFirstDraw)
     {
-
         // get last pixel before interpolation initializes
-        QPointF startStrokes =  m_pStrokeManager->interpolateStart(getLastPixel());
-        mStrokePoints << mEditor->view()->mapScreenToCanvas( startStrokes );
-        mStrokePressures << m_pStrokeManager->getPressure();
-
+        QPointF startStrokes = strokeManager()->interpolateStart(getLastPixel());
+        mStrokePoints << mEditor->view()->mapScreenToCanvas(startStrokes);
+        mStrokePressures << strokeManager()->getPressure();
     }
     else
     {
